// Step of the tutorial we're in:
uint tutorialstep = 0;
bool hideme = false;

// RenderInterface to hide it when the overlay isn't open
// as you need the overlay to go from step to step regardless.
void RenderInterface()
{
    // hide if unwanted
    if (!hideme)
        switch (tutorialstep) { // render according to the tutorial step
        case 0:
            // Tutorial step 1: rectangle
            nvg::BeginPath();
            nvg::Rect(100,100,300,150);
            nvg::FillColor(vec4(1, 0, 0, 0.5));
            nvg::Fill();
            nvg::ClosePath();
            break;

        case 1: 
            // Tutorial step 2: rounded rectangle
            nvg::BeginPath();
            nvg::RoundedRect(100, 100, 300, 150, 10);
            nvg::FillColor(vec4(1, 0, 0, 0.5));
            nvg::Fill();
            nvg::ClosePath();
            break;

        case 2:
            // Tutorial step 3: triangles
            nvg::BeginPath();
            
            nvg::MoveTo(vec2(100,100)); // top left corner
            nvg::LineTo(vec2(400,100)); // top right corner: 100 (x) + 300 (w), y remains
            nvg::LineTo(vec2(100,250)); // bottom left corner: x remains, 100 (y) + 150 (h)
            nvg::LineTo(vec2(100,100)); // back to top left
            
            nvg::FillColor(vec4(1, 0, 1, 0.5));
            nvg::Fill();
            
            nvg::ClosePath();
            break;

        case 3:
            // Tutorial step 4: triangle outline
            nvg::BeginPath();
    
            nvg::MoveTo(vec2(100,100)); 
            nvg::LineTo(vec2(400,100)); 
            nvg::LineTo(vec2(100,250)); 
            nvg::LineTo(vec2(100,100)); 

            nvg::StrokeColor(vec4(1, 0.5, 0, 0.5));
            nvg::StrokeWidth(5.5);
            nvg::Stroke();

            nvg::ClosePath();
            break;
        
        case 4:
            // Tutorial note 1: concave filling
            nvg::BeginPath();

            nvg::MoveTo(vec2(100,100)); 
            nvg::LineTo(vec2(150,150));
            nvg::LineTo(vec2(200,100));
            nvg::LineTo(vec2(200,200));
            nvg::LineTo(vec2(100,200));
            nvg::LineTo(vec2(100,100));

            nvg::StrokeColor(vec4(1, 0.5, 0, 0.5));
            nvg::StrokeWidth(5.5);
            nvg::Stroke();

            nvg::FillColor(vec4(1, 0, 0, 0.5));
            nvg::Fill();

            nvg::ClosePath();
            break;

        case 5:
            // Tutorial step 4: Gradients and paints
            nvg::BeginPath();
            nvg::Rect(100, 100, 300, 500);
            nvg::FillPaint(nvg::BoxGradient(100,200,300,300, 150, 100, vec4(1,0,0,1), vec4(1,1,0,1)));
            nvg::Fill();
            nvg::ClosePath();

            nvg::BeginPath();
            nvg::Rect(500, 100, 300, 500);
            nvg::FillPaint(nvg::LinearGradient(vec2(500,100), vec2(500,600), vec4(1,0,0,1), vec4(1,1,0,1)));
            nvg::Fill();
            nvg::ClosePath();

            nvg::BeginPath();
            nvg::Rect(900, 100, 300, 500);
            nvg::FillPaint(nvg::RadialGradient(vec2(1050, 350), 100, 200, vec4(1,0,0,1), vec4(1,1,0,1)));
            nvg::Fill();
            nvg::ClosePath();
            break;

        case 6:
            // Tutorial step 5: Bezier Quad I
            nvg::BeginPath();

            // start point: (100, 100)
            nvg::MoveTo(vec2(100, 100)); 

            // control point: (200, 400), end point: (300, 100)
            nvg::QuadTo(vec2(200, 400), vec2(300, 100)); 
            
            nvg::StrokeColor(vec4(1, 0.5, 0, 0.5));
            nvg::StrokeWidth(5.5); nvg::Stroke();

            nvg::ClosePath();
            break;

        case 7:
            // Tutorial step 6: Bezier Quad II
            nvg::BeginPath();

            // start point: (100, 100)
            nvg::MoveTo(vec2(100, 100)); 

            // control point: (150, 400), end point: (300, 300)
            nvg::QuadTo(vec2(150, 400), vec2(300, 300)); 

            nvg::StrokeColor(vec4(1, 0.5, 0, 0.5));
            nvg::StrokeWidth(5.5); nvg::Stroke();

            nvg::ClosePath();
            break;

        case 8:
            // Tutorial step 7: Bezier Quad III
            nvg::BeginPath();

            nvg::MoveTo(vec2(100, 100)); 
            nvg::QuadTo(vec2(150, 400), vec2(300, 300)); 
            nvg::QuadTo(vec2(450, 200), vec2(300, 400));
            nvg::QuadTo(vec2(150, 600), vec2(600, 600));
            nvg::QuadTo(vec2(800, 600), vec2(600, 300));

            nvg::StrokeColor(vec4(1, 0.5, 0, 0.5));
            nvg::StrokeWidth(5.5); nvg::Stroke();

            nvg::ClosePath();
            break;
    

        case 9:
            // Tutorial step 8: Bezier Cubic I
            nvg::BeginPath();

            nvg::MoveTo(vec2(100, 100)); 
            nvg::BezierTo(vec2(150, 400), vec2(450, 200), vec2(300, 400)); 

            nvg::StrokeColor(vec4(0, 0.5, 1, 0.5));
            nvg::StrokeWidth(5.5); nvg::Stroke();

            nvg::ClosePath();
            break;

        case 10:
            // Tutorial step 9: Bézier Cubic II
            nvg::BeginPath();

            nvg::MoveTo(vec2(100, 100)); 
            nvg::BezierTo(vec2(150, 400), vec2(450, 200), vec2(300, 400));
            nvg::BezierTo(vec2(150, 600), vec2(800, 600), vec2(600, 300));

            nvg::StrokeColor(vec4(0, 0.5, 1, 0.5));
            nvg::StrokeWidth(5.5); nvg::Stroke();

            nvg::ClosePath();
            break;

        default: // reset the tutorial step, you went too far.
            tutorialstep = 0;
            break;
        }
}

void RenderMenu()
{
    // add menu items to go to the right Tutorial Steps
    if (UI::BeginMenu(ColoredString("$f00" + Icons::PaintBrush + "$fff NanoVG Tutorial"))) {

        if (UI::MenuItem(ColoredString("$f00" + Icons::Forward + "$fff Next")))         tutorialstep++;
        if (UI::MenuItem(ColoredString("$f00" + Icons::FastBackward + "$fff Restart"))) tutorialstep=0;
        if (UI::MenuItem(ColoredString("$f00" + Icons::PowerOff + "$fff Hide")))        hideme = !hideme;

        UI::EndMenu();
    }
}
